@@ -313,8 +313,43 @@ class DashboardSession(object):
         
         with open(pickle_path, 'rb') as f:
             project = pickle.load(f)
-        
+
+        project = self.__update_project_filepaths(project)
+
         self.project_list[project_name] = project
+        return project
+
+    def __update_project_filepaths(self, project):
+        
+        # Update filepath references for the project
+        project.dashboard_dir = self.dashboard_dir
+
+        # Build filename for config file
+        config_filename = project.project_name + r'_Plant_Config_MACRO.xlsm'
+        project.config_filepath = os.path.join(project.dashboard_dir,
+                                        project.project_directory,
+                                        project.project_name,
+                                       'Plant_Config_File',
+                                        config_filename)
+
+        # Find Powertrack file
+        project.data_AE_dir = os.path.join(project.dashboard_dir,
+                                        project.project_directory,
+                                        project.project_name,
+                                        'Powertrack_data')
+        project.data_AE_all_files = [f for f in os.listdir(project.data_AE_dir) if os.path.isfile(os.path.join(project.data_AE_dir, f))]
+        data_AE = [s for s in project.data_AE_all_files if project.data_source in s]
+
+        # Build filename for Powertrack file
+        project.powertrack_filepath = os.path.join(project.dashboard_dir, project.project_directory, project.project_name, 'Powertrack_data', data_AE[0])
+
+        # Check for pickle jar folder & create if it doesn't exist
+        project.pickle_jar = os.path.join(project.dashboard_dir,
+                                       project.project_directory,
+                                       project.project_name,
+                                       'Pickle_Jar')
+        
+        return project
 
 
     def load_pickles(self, project_list, year=None):
@@ -430,27 +465,25 @@ class DashboardSession(object):
             project_name (str, Project, or list): A project to draw plots on for analysis.
             plot_order (list or str, optional): A list of plots to draw. This can be
                 any number of plots from one to all plots. Defaults to all plots in the below order.
-            +------------+------------------------------
-            | Plot Alias | Plot Description            |
-            +============+=============================+
-            | xplot_met  | Crossplot                   |
-            +------------+-----------------------------+
+            Default Order:
+            
                 * xplot_met_poa: Crossplot of meter & POA data.
-            * `xplot_temp`: Crossplot of meter & POA, colored by Tamb.
-            * `temps`: Tcell temperature comparison.
-            * `inv`: Inverters.
-            * `pr`: Hourly PR plot.
-            * `8760`: Measured vs 8760 comparison.
-            * `weather`: Weather sensors.
-            * `met_corr`: Meter corrections.
-            * `met_corr_dif`: Meter correction dif.
-            * `poas`: POA sensors.
-            * `met_poa`: Meter & POA avg.
-            * `ghi`: GHI sensors.
-            * `irrad`: POA & GHI sensors.
-            * `tz`: Timezone check.
-            * `losses`: Losses by type.
-            * `poa_corr`: POA correlation check.
+                * `xplot_temp`: Crossplot of meter & POA, colored by Tamb.
+                * `temps`: Tcell temperature comparison.
+                * `inv`: Inverters.
+                * `pr`: Hourly PR plot.
+                * `8760`: Measured vs 8760 comparison.
+                * `weather`: Weather sensors.
+                * `met_corr`: Meter corrections.
+                * `met_corr_dif`: Meter correction dif.
+                * `poas`: POA sensors.
+                * `met_poa`: Meter & POA avg.
+                * `ghi`: GHI sensors.
+                * `irrad`: POA & GHI sensors.
+                * `tz`: Timezone check.
+                * `losses`: Losses by type.
+                * `poa_corr`: POA correlation check.
+
             **kwargs: See below.
         
         Keyword Args:
